<?php


namespace Tfaf\Inc\Base;

require_once TFAF_PLUGIN_PATH . 'Inc/Api/SettingsApi.php';
require_once TFAF_PLUGIN_PATH . 'Inc/Api/Callbacks/AdminCallbacks.php';
require_once TFAF_PLUGIN_PATH . 'Inc/Api/Callbacks/CmeCallbacks.php';
require_once TFAF_PLUGIN_PATH . 'Inc/Base/BaseController.php';

use Tfaf\Inc\Api\Callbacks\CmeCallbacks;
use Tfaf\Inc\Api\SettingsApi;
use Tfaf\Inc\Api\Callbacks\AdminCallbacks;

class CustomMenuController extends BaseController
{

    public $callbacks;
    public $cme_callbacks;

    public $settings;

    public $custom_menu_entries = array();

    public $subpages = array();

    /**
     * Register the Custom Menu Controller
     */
    public function register()
    {

        // Check if the Custom Menu Controller is activated
        if (!$this->activated('cem_manager')) {
            return;
        }

        // Check if Asgaros Forum is activated
        if (!is_plugin_active('asgaros-forum/asgaros-forum.php')) {
            return;
        }


        $this->settings = new SettingsApi();
        $this->callbacks = new AdminCallbacks();
        $this->cme_callbacks = new CmeCallbacks();

        $this->custom_menu_entries = get_option('tfaf_custom_menu') ?: array();

        $this->setSubPages();

        $this->setSettings();
        $this->setSections();
        $this->setFields();

        $this->settings->addSubPages($this->subpages)->register();

        // check if some custom menu entries are set
        if (!empty($this->custom_menu_entries)) {
            add_filter('asgarosforum_custom_header_menu', array($this, 'addHeaderMenu'));
        }
    }

    // Add all the custom menu entries to the header menu
    public function addHeaderMenu()
    {

        foreach ($this->custom_menu_entries as $custom_menu_entry) {
            // check the url
            $menu_url = esc_url($custom_menu_entry['menu_url']);

            if ($menu_url[0] == '/') {
                $menu_url = get_home_url() . $menu_url;
            }

            // Check if user is logged in or has to be locked in
            if (!isset($custom_menu_entry['menu_only_users']) || is_user_logged_in()) {
                $new_tab = (isset($custom_menu_entry['menu_new_tab'])) ? ' target="_blank"' : '';
                echo '<a href="' . $menu_url . '"' . $new_tab . '>' .
                    esc_html($custom_menu_entry['menu_link_text']) . '</a>';
            }
        }
    }

    /**
     * Set settings for Custom Menu Controller
     */
    public function setSettings()
    {
        $args = array(
            array(
                'option_group' => 'tfaf_custom_menu_settings',
                'option_name' => 'tfaf_custom_menu',
                'callback' => array($this->cme_callbacks, 'cmeSanitize')
            )
        );

        $this->settings->setSettings($args);
    }

    /**
     * Set section for Custom Menu Controller
     */
    public function setSections()
    {
        $args = array(
            array(
                'id' => 'tfaf_cme_index',
                'title' => esc_html__('Custom Menu Entry', 'toolbox-for-asgaros-forum'),
                'callback' => array($this->cme_callbacks, 'cmeSectionManager'),
                'page' => 'tfaf_cme'
            )
        );

        $this->settings->setSections($args);
    }

    /**
     * Set fields for Custom Menu Controller
     */
    public function setFields()
    {

        $args = array(
            array(
                'id' => 'menu_position',
                'title' => esc_html__('Menu Position', 'toolbox-for-asgaros-forum'),
                'callback' => array($this->cme_callbacks, 'position'),
                'page' => 'tfaf_cme',
                'section' => 'tfaf_cme_index',
                'args' => array(
                    'option_name' => 'tfaf_custom_menu',
                    'label_for' => 'menu_position',
                    'placeholder' => ''
                )
            ),
            array(
                'id' => 'menu_link_text',
                'title' => esc_html__('Link Text', 'toolbox-for-asgaros-forum'),
                'callback' => array($this->cme_callbacks, 'textField'),
                'page' => 'tfaf_cme',
                'section' => 'tfaf_cme_index',
                'args' => array(
                    'option_name' => 'tfaf_custom_menu',
                    'label_for' => 'menu_link_text',
                    'placeholder' => esc_html__('e.g. User Guidelines', 'toolbox-for-asgaros-forum')
                )
            ),
            array(
                'id' => 'menu_url',
                'title' => esc_html__('Url', 'toolbox-for-asgaros-forum'),
                'callback' => array($this->cme_callbacks, 'urlField'),
                'page' => 'tfaf_cme',
                'section' => 'tfaf_cme_index',
                'args' => array(
                    'option_name' => 'tfaf_custom_menu',
                    'label_for' => 'menu_url',
                    'placeholder' => esc_html__('e.g. /guidelines or https://www.google.de', 'toolbox-for-asgaros-forum')
                )
            ),
            array(
                'id' => 'menu_new_tab',
                'title' => esc_html__('Open in new Tab', 'toolbox-for-asgaros-forum'),
                'callback' => array($this->cme_callbacks, 'checkboxField'),
                'page' => 'tfaf_cme',
                'section' => 'tfaf_cme_index',
                'args' => array(
                    'option_name' => 'tfaf_custom_menu',
                    'label_for' => 'menu_new_tab',
                    'class' => 'ui-toggle'
                )
            ),
            array(
                'id' => 'menu_only_users',
                'title' => esc_html__('Show only logged in users', 'toolbox-for-asgaros-forum'),
                'callback' => array($this->cme_callbacks, 'checkboxField'),
                'page' => 'tfaf_cme',
                'section' => 'tfaf_cme_index',
                'args' => array(
                    'option_name' => 'tfaf_custom_menu',
                    'label_for' => 'menu_only_users',
                    'class' => 'ui-toggle'
                )
            )
        );

        $this->settings->setFields($args);
    }

    /**
     * Set subpages for Custom Menu Controller to admin menu
     */
    public function setSubPages()
    {
        $this->subpages = array(
            array(
                'parent_slug' => 'toolbox_asgaros',
                'page_title' => esc_html__('Custom Header Menu', 'toolbox-for-asgaros-forum'),
                'menu_title' => esc_html__('Custom Menu', 'toolbox-for-asgaros-forum'),
                'capability' => 'manage_options',
                'menu_slug' => 'tfaf_custom_menu',
                'callback' => array($this->callbacks, 'customMenu')
            )
        );
    }

}